==> nextcloud-16.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/nb.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern ressurs {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern ressurs",
    "Remote share password" : "Passord for ekstern ressurs",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern ressurs",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
    "Server to server sharing is not enabled on this server" : "Server til server deling er ikke aktivert på denne serveren",
    "Couldn't establish a federated share." : "Kunne ikke etablere en sammenknyttet ressurs",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke etablere en sammenknyttet ressurs, kanskje passordet var feil.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Sammenknyttet ressurs forespurt, du vil motta en invitasjon. Sjekk varslene dine.",
    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en sammenknyttet skydeling med den samme brukeren",
    "File is already shared with %s" : "Filen er allerede delt med %s",
    "Could not find share" : "Kunne ikke finne ressurs",
    "Federated sharing" : "Sammenknyttet deling",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du har mottatt \"%3$s\" som en ekstern deling fra %1$s (på vegne av %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du har mottatt {share} som en ekstern deling fra {user} (på vegne av {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Du har mottatt \"%3$s\" som en ekstern deling fra %1$s",
    "You received {share} as a remote share from {user}" : "Du mottok {share} som en fjerndeling fra {user}",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky, se %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky",
    "Sharing" : "Deling",
    "Federated file sharing" : "Sammenknyttet fildeling",
    "Federated Cloud Sharing" : "Sammenknyttet skydeling",
    "Open documentation" : "Åpne dokumentasjonen",
    "Adjust how people can share between servers." : "Juster hvordan folk kan dele mellom servere.",
    "Allow users on this server to send shares to other servers" : "Tillat at brukere på denne serveren sender delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
    "Search global and public address book for users" : "Søk global og offentlige adressebøker etter brukere",
    "Allow users to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
    "Federated Cloud" : "Sammenknyttet sky",
    "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
    "Share it so your friends can share files with you:" : "Del den slik at venner kan dele filer med deg:",
    "Add to your website" : "Legg på nettsiden din",
    "Share with me via Nextcloud" : "Del med meg via Nextcloud",
    "HTML Code:" : "HTML-kode:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/federatedfilesharing/l10n/nb.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern ressurs {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern ressurs",
    "Remote share password" : "Passord for ekstern ressurs",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern ressurs",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere",
    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
    "Server to server sharing is not enabled on this server" : "Server til server deling er ikke aktivert på denne serveren",
    "Couldn't establish a federated share." : "Kunne ikke etablere en sammenknyttet ressurs",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke etablere en sammenknyttet ressurs, kanskje passordet var feil.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Sammenknyttet ressurs forespurt, du vil motta en invitasjon. Sjekk varslene dine.",
    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en sammenknyttet skydeling med den samme brukeren",
    "File is already shared with %s" : "Filen er allerede delt med %s",
    "Could not find share" : "Kunne ikke finne ressurs",
    "Federated sharing" : "Sammenknyttet deling",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Du har mottatt {share} som en ekstern deling fra {user} (på vegne av {behalf})",
    "You received {share} as a remote share from {user}" : "Du mottok {share} som en fjerndeling fra {user}",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky, se %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky",
    "Sharing" : "Deling",
    "Federated file sharing" : "Sammenknyttet fildeling",
    "Federated Cloud Sharing" : "Sammenknyttet skydeling",
    "Open documentation" : "Åpne dokumentasjonen",
    "Adjust how people can share between servers." : "Juster hvordan folk kan dele mellom servere.",
    "Allow users on this server to send shares to other servers" : "Tillat at brukere på denne serveren sender delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
    "Search global and public address book for users" : "Søk global og offentlige adressebøker etter brukere",
    "Allow users to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
    "Federated Cloud" : "Sammenknyttet sky",
    "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
    "Share it so your friends can share files with you:" : "Del den slik at venner kan dele filer med deg:",
    "Add to your website" : "Legg på nettsiden din",
    "Share with me via Nextcloud" : "Del med meg via Nextcloud",
    "HTML Code:" : "HTML-kode:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du har mottatt \"%3$s\" som en ekstern deling fra %1$s (på vegne av %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Du har mottatt \"%3$s\" som en ekstern deling fra %1$s"
},
"nplurals=2; plural=(n != 1);");
